{% extends 'base.html' %}
{% from 'packages/macros.html' import list_packages %}
{% block title %}Installed {{ type }} packages{% endblock %}
{% block header %}Installed <code>{{ type }}</code> packages{% endblock %}
{% block content %}
  {{ list_packages(packages, type) }}
{% endblock content %}
