/* Page */

	/* Give extra space to the fixed navbar */
	body { padding-top: 70px; }

/* Headers */

	/* Mute environment links in headers */
	header a.environment { color: #999; }
	header a.environment:hover { color: #666; }

/* Content */

	/* Color code blocks in links differently */
	a code { color: #428BCA; /*background-color: #F4F8FA;*/ }
	a:hover code { color: #2A6496; }

	/* Remove the code background highlighting */
	code {
		background-color: transparent;
		border-radius: 0;
		padding: 0;
	}

	.environment-links {
		font-size: 80%;
		color: #CCC;
		float: right;
	}
	.environment-links a { color: #8EB9DF; }
	.environment-links a:hover { color: #428BCA; }

/* Footer */

	/* Add margins around the footer so it's not close to the text */
	footer {
		padding-top: 1em;
		text-align: center;
	}

	/* Use muted colors for the footer */
	footer a { color: #666; }
	footer a:hover { color: #333; }

/* Navigation */

	/* Highlight 'All environments' in the environment dropdown */
	#environment_all {
		font-weight: bold;
	}
